#
# spec file for package scap-workbench
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           scap-workbench
Version:        1.1.1
Release:        3.23
Summary:        A SCAP scanner and SCAP content editor
License:        GPL-3.0
Group:          System/Security
Url:            https://fedorahosted.org/scap-workbench/
Source:         https://fedorahosted.org/released/scap-workbench/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  openscap-devel
# SLE 11 SP3: libopenscap needs libxslt without requiring it
# libxslt nees pcre
%if 0%{?suse_version} < 1140
BuildRequires:  libxslt-devel
BuildRequires:  pcre-devel
%endif
BuildRequires:  pkg-config
# QXmlQuery is in 4.8 and later
BuildRequires:  libqt4-devel >= 4.8
BuildRequires:  update-desktop-files
%if 0%{?suse_version} >= 1140
BuildRequires:  libwebkitgtk-devel
%else
BuildRequires:  libwebkit-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The main goal of this application is to lower the initial barrier of
using SCAP. Therefore, the scope of very narrow - scap-workbench only
scans a single machine and only with XCCDF/SDS (no direct OVAL
evaluation). The assumption is that this is enough for users who want
to scan a few machines and users with huge amount of machines to scan
will just use scap-workbench to test or hand-tune their content before
deploying it with more advanced (and harder to use) tools like
spacewalk.

%package doc
Summary:        Documentation for scap-workbench
Group:          Documentation

%description doc
This package provides HTML documentation for scap-workbench.

%prep
%setup -q

%build
%if 0%{?cmake}
%cmake -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} -DCMAKE_INSTALL_LIBEXECDIR=%{_libdir}/%{name}
%else
rm -rf build
mkdir build
(cd build;
 cmake -DCMAKE_INSTALL_PREFIX=/usr\
   -DCMAKE_VERBOSE_MAKEFILE=TRUE\
   -DCMAKE_SKIP_RPATH=1\
   -DPACKAGE_ARCHITECTURE=`uname -m`\
   -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name}\
   -DCMAKE_INSTALL_LIBEXECDIR=%{_libdir}/%{name}\
   ..)
%endif
(cd build; make %{?jobs:-j%jobs})

%install
(cd build; %make_install)

%if 0%{?suse_version}
%suse_update_desktop_file -i -u %name Utility DesktopUtility
%endif

%files
%defattr(-,root,root,0755)
%doc README.md COPYING
%{_bindir}/%{name}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%name.appdata.xml
%dir %{_datadir}/%name
%{_datadir}/%name/*.png
%dir %{_datadir}/%name/translations
%{_datadir}/%name/translations/README
%{_datadir}/applications/%name.desktop
%{_datadir}/pixmaps/%{name}*
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/%{name}*
%{_mandir}/man8/%{name}*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*sh
%exclude %{_docdir}/%{name}/*.html

%files doc
%defattr(-,root,root,0755)
%doc %{_docdir}/%{name}/*.html

%changelog
* Mon Oct 12 2015 kkaempf@suse.com
- Update to 1.1.1
  Bugfix release
* Mon Oct 12 2015 kkaempf@suse.com
- take ownership of /usr/share/polkit-1*
* Thu Mar 26 2015 meissner@suse.com
- updated to 1.1.0
  Shiny new major release of SCAP Workbench. A lot of UX improvements
  and many new exciting features including a much better SCAP Security
  Guide integration. Downstreams are now encouraged to depend on
  scap-security-guide.
* Thu Feb  5 2015 kkaempf@suse.com
- Require libqt4-devel >= 4.8
* Fri Jan  9 2015 meissner@suse.com
- version 1.0.3
  This is a maintenance release with many bugfixes, usability improvements
  and documentation fixes. All users are recommended to update.
  See https://fedorahosted.org/scap-workbench/query?group=status&milestone=1.0.3
  for full list of changes.
- scap-workbench-0.8.6.patch: upstream
* Sat Feb  8 2014 kkaempf@suse.com
- fix path to bash, add scap-workbench-0.8.6.patch
* Sat Feb  8 2014 kkaempf@suse.com
- Initial version 0.8.6
